@@ -3,6 +3,8 @@ import os
 import json
 from jovian.utils.constants import RC_FILENAME
 
+_current_slug = None
+
 
 def rcfile_exists():
     """Check if .jovianrc exists"""
@@ -26,18 +28,38 @@ def get_rcdata():
     return data
 
 
-def get_notebook_slug(filename):
+def get_notebook_slug(filename, cache_result=True):
     """Get the gist slug for a notebook filename"""
+    global _current_slug
     data = get_rcdata()
-    if (filename in data['notebooks']):
-        return data['notebooks'][filename]['slug']
+    if (filename in data.get('notebooks', {})):
+        slug = data['notebooks'][filename]['slug']
+        if slug and cache_result:
+            _current_slug = slug
+        return slug
 
 
-def set_notebook_slug(filename, slug):
+def get_cached_slug():
+    """Get the cached notebook slug"""
+    global _current_slug
+    return _current_slug
+
+
+def set_notebook_slug(filename, slug, cache_result=True):
     """Set the gist slug for a notebook filename"""
+    global _current_slug
     data = get_rcdata()
     data['notebooks'][filename] = {'slug': slug}
     save_rcdata(data)
+    if cache_result:
+        _current_slug = slug
+    return slug
+
+
+def reset_notebook_slug():
+    """Reset cached notebook slug"""
+    global _current_slug
+    _current_slug = None
 
 
 def make_rcdata(filename, slug):
